%define debug_package %{nil}


Summary:	Programs to compute MD5, SHA-1, or SHA-256 message digests on files

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		md5deep
Version:	4.4
Release:	1%{?dist}

License:	GPL
URL:		http://md5deep.sourceforge.net/

Group:		Applications/Forensics Tools

Source:		hashdeep-release-%{version}.tar.gz
BuildRoot: 	%{_tmppath}/rpm-root-%{name}-v%{version}
BuildRequires:	gcc-c++, libstdc++-devel
BuildRequires:	autoconf, automake

%description
md5deep is a cross-platform set of programs to compute MD5, SHA-1, or SHA-256
message digests on an arbitrary number of files. The programs run on Windows,
Linux, *BSD, OS X, Solaris, and should run on most other platforms. md5deep
is similar to the md5sum program found in the GNU Coreutils package, but
has the following additional features:
    * Recursive operation - md5deep is able to recursive examine an entire directory tree. That is, compute the MD5
      for every file in a directory and for every file in every subdirectory.
    * Time estimation - md5deep can produce a time estimate when it's processing very large files.
    * Comparison mode - md5deep can accept a list of known hashes and compare them to a set of input files. The program can
      display either those input files that match the list of known hashes or those that do not match. Hashes sets can be drawn
      from the National Software Reference Library, iLook Investigator, Hashkeeper, or md5sum. Users are welcome to add functionality
      to read other formats too!
    * File type mode - md5deep can process only files of a certain type, such as regular files, block devices, etc. 

%prep
%setup -n hashdeep-release-%{version}
sh bootstrap.sh
%configure --prefix=/usr --mandir=/usr/share/man --bindir=/usr/bin

%build
CFLAGS=${RPM_OPT_FLAGS} make

%install
%makeinstall

%clean
rm -rf ${RPM_BUILD_ROOT}

%files
%defattr(444, bin, bin, 0755)
%doc  COPYING INSTALL NEWS TODO README AUTHORS ChangeLog
%attr(444, bin, bin)	%{_mandir}/man1/*
%attr(555, bin, bin)	%{_bindir}/*

%changelog
* Wed Jan 01 2014 Lawrence Rogers <lrr@cert.org> 4.4-1
* Release 4.4-1
        * src/dig.cpp: Support deduplication reparse points, issue 307.
        * src/multihash.cpp (hash_context_obj::multihash_finalize): removed old code that was commented out.
        * src/dig.cpp: Fixed issue 301 re: removing double dots from path
        * Makefile.am: Removed sha3deep target
        * hashlist.cpp: Fixes problem with known files with commas in filename.
        * configure.ac: Added patch from dago to check for MAP_FILE
        * src/dig.cpp: Experimental change to parse single instance storage (SIS) junction points.
        * src/hashlist.cpp: Added experimental mode for case insensitive matching. Also changes in main.cpp, main.h, and display.cpp
        * src/Makefile.am: Added sha3deep
        * src/main.h: Added SHA3 defines
        * src/main.cpp: Added SHA3 code
        * src/common.h: Increased max size of context structure for SHA-3
        * man/hashdeep.1: Clarified Unicode statements
        * main.cpp: Converting break statements which fall through to consistent style.
        * main.cpp: Added checks in hashdeep against user errors on command line
        * dig.cpp: Adding specific message regarding SIS reparse points.
        * blake: Removed code which won't be used
        * configure.ac: Uncommented check for big endian systems.
        * src/threadpool.cpp: Renamed ERR function to avoid conflicts on SunOS and derivates.
        * man/md5deep.1, hashdeep.1: Typos

* Mon Oct 24 2012 Lawrence Rogers <lrr@cert.org> 4.3-1
* Release 4.3-1
	Bug Fixes
		Fixed check for endian-ness, affecting hash generation on
		big-endian platforms.

		Fixed minor bugs related to OpenSolaris.

* Mon Jun 11 2012 Lawrence Rogers <lrr@cert.org> 4.2-1
* Release 4.2-1
	Bug Fixes
		Fixed padding in Tiger hashes for large files

* Tue Feb 14 2012 <md5deep@jessekornblumn.com> 4.1-1
* Release 4.1-1
	New Features
		Added expert mode option to parse Windows PE files
	Bug Fixes
		Fixed junction point handling on Win32

* Fri Jan 27 2012 <md5deep@jessekornblumn.com> 4.0.1-1
* Release 4.0.1-1
	* Bug Fixes
		Fixed hang on DFXML generation on Win32
		Fixed incorrect hashes via stdin on Win32
		Fixed "Too many open files" error on OS X
		Doc files in Win32 have been corrected.

* Fri Jan 6 2012 <md5deep@jessekornblumn.com> 4.0.0-1
* Release 4.0.0-1
	* New Features
		Rewrote most of the program in C++.
		Enabled multiprocessor support on all platforms.
		Removed ten character limit on file size mode
	* Bug Fixes
		Too numerous to count!

* Tue Jul 26 2011 <md5deep@jessekornblumn.com> 3.9.2-1
* Release 3.9.2-1
	New Features
		Added a warning message when running 32-bit versions of the programs on a 64-bit system.
	Bug Fixes
		Fixed a cosmetic bug in the hashdeep header.

* Mon May 31 2011 <md5deep@jessekornblumn.com> 3.9.1-1
* Release 3.9.1-1
	New Features
		Added -f mode to get the list of input files from a file on the disk.
		Added 64-bit executables for Windows.
	Bug Fixes
		Fixed a critical bug regarding hashdeep's ability to compute correct hashes on standard input.
		Fixed a cosmetic bug regarding the error messages for piecewise mode.
		Fixed a cosmetic bugs regarding processing standard input in piecewise mode.
		Fixed a bug regarding processing known hash files which have parenthesis in the filename.
		Clarified documentation regarding multipliers in piecewise mode. They are IEC multipliers, or blocks of 1,024. Side note: also spelled 'multipliers' correctly.

* Thu Apr 21 2011 <md5deep@jessekornblumn.com> 3.9-1
* Release 3.9-1
	  New Features
 
	  Bug Fixes
	      Fixed a critical bug in hashdeep regarding processing standard input
	      Added -f mode to get the list of input files from

* Fri Apr 15 2011 <md5deep@jessekornblumn.com> 3.8-1
* Release 3.8-1
	  New Features
	      Added -f mode to get the list of input files froma file on the disk.
	      Added 64-bit executables for Windows.
	  Bug Fixes
	      Fixed a cosmetic bug regarding the error messages for piecewise mode.

* Sun Dec 19 2010 Jessee Kornblum <md5deep@jessekornblumn.com> 3.7
* Release 3.7-1
	See Changelog for details

* Wed Mar 23 2010 Jesse Kornblum <md5deep@jessekornblumn.com>
* Release 3.6-1
	* Version bump to 3.6 and release

	* Documented expert mode in hashdeep man page, getting started
	  guide. Also made a few tweaks to the md5deep documentation.

	* Added some error checking routines to helpers
	

* Wed Mar 06 2010 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Cleaned up md5deep/main.h comment styles. Also added a field
	  to the state variable to keep track of the file's type. This
	  is was handy for...

	* Updating file size computation to use results of stat 
	  operation normally done anyway during dig phase.
	

* Wed Feb 26 2010 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Adding 'expert' mode from md5deep to hashdeep.
	

* Wed Feb 25 2010 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Changed all contact email addresses to research account at
	  jessekornblum.com. The 'md5deep' account will be deprecated.
	

* Wed Jan 09 2010 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Finished updating download links. Updated and published
	  Hashdeep quick start guide

	
* Wed Dec 30 2009 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Converting documentation update to use rsync+ssh to upload content
	

* Wed Dec 29 2009 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Version bump to 3.5.1

	* Attempting to fix bug 2922415 involving zero byte files

	* Added a few items to the TODO list

	* Started web page cleanup


* Wed Dec 21 2009 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Attempting to fix bug 2919014 regarding hashdeep and its
	  failure to detect when files go missing during an audit
	  if there is another, identical file in a different location

	* Cleanup on md5deep code for -f mode

	* Revised list of new features for release 3.5


* Wed Sep 24 2009 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Again revised patch 2855502 to handle the last read of
	  files/stdin when no data is read. This happens when the
	  file size is an exact multiple of the piecewise size.
	

* Wed Sep 16 2009 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Updated broken link on web page for Whirlpool.
	

* Wed Sep 09 2009 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Applied a modified version of patch 2855502 to fix file size 
	  computation for piecewise hashing of stdin.
	

* Wed Jul 11 2009 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Added draft of Hashdeep Getting Started guide
	

* Wed Jul 10 2009 Jesse Kornblum <md5deep@jessekornblumn.com>

	* Fixed method to read list of files to hash from a file.
	

* Wed Jun 14 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Experimenting with reading list of files to hash from another
	  file in md5deep.
	

* Wed May 22 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Closed search handle in is_junction_point in response
	  to bug 2795587.

	* Attempting to fix -n mode by removing check in is_known_hash
	  for NULL parameters.

	
* Wed Apr 10 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Experimenting with stopping file read on "Invalid argument" errors
	  to avoid crashes on Win32.
	

* Wed Apr 04 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Version bump to 3.3 and released.
	

* Wed Mar 26 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Updated timestamp code to support 64-bit functions on Windows.
	

* Wed Mar 01 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Experimenting by skipping *all* junction points on
	  Windows. We'll display a message with 'unknown' status
	  values.

	* Version bump to 3.3-002.
	

* Wed Feb 08 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 	

	* Removed email address from all files. Too many spammers, sorry.

	
* Wed Jan 26 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Cleaned up code for version 3.2 release. Commented out NTFS
	  junction point detection for now. 

	* Applied patch 2535551 to Makefile.am to use LDADD variable
	  instead of AM_LDFLAGS.
	

* Wed Jan 25 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Added experimental CSV mode, -c
	

* Wed Jan 16 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Switching from /* comments to // comments in code to allow
	  for commenting out whole functions when necessary.

	* Added sanity checking to helper functions, changed some variable
	  names from single character values to more descriptive names.
	

* Wed Jan 15 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Removed vestigial code from include/md5.h and the other
	  algorithms in that directory. This was code that had been
	  commented out for a while now.

	* Updated email address in this ChangeLog for all entries.

	* Added include directory to the 'make preflight' directive
	
	
* Wed Jan 14 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Fixed chop_line call against uninitialized variable
	  in hashdeep/match.c. Added sanity checking to chop_line
	  to keep this from happening again.

	* Added file format documentation for hashdeep.

	
* Wed Jan 09 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Changed hashdeep to break long command lines into multiple
	  lines in the headers of known files. Not doing so leads to
	  problems with extremely long lines. Those lines end up as
	  (harmless) warnings about bad hashes. See bug report 2496029
	  for more details.
	

* Wed Jan 08 2009 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Added detection and avoidance of NTFS Junction Points
	  to avoid infinite loops on Windows systems. 
	  See bug report 2492520 for more details.
	
	* Updated email address in AUTHORS file.


* Wed Oct 22 2008 Jesse Kornblum <md5deep@jessekornblumn.com> 
	
	* Rewrote the parsing of known files in hashdeep in response 
	  to bug 2184219
	  relating to filenames with commas in them. We now determine
	  the expected number of columns from the header and use that
	  to parse the remainder of the file.
	  This should eventually allow us to remove our dependency on
	  strsep.

	* Fixed a minor hashdeep bug where hashes were considered
	  invalid if they contained too few characters, but not too many.

	
* Wed Sep 25 2008 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Updated hashdeep usage message to reflect that MD5 and SHA-256
	  are the default algorithms used, not SHA-1.
	

* Wed Sep 23 2008 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Changing stat functions on Windows to handle 64-bit
	  file sizes (i.e. call _tstat64 instead of _tstat)

	
* Wed Sep 14 2008 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Experimenting with new time estimation calculation
	

* Wed Aug 13 2008 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Updated contact email addres and reconfigured.

	* Applied patch 2026326 to fix VPATH build for manpages.

	
* Wed Jul 27 2008 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Reconfigured with latest tools

	
* Wed Jul 20 2008 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Removed debugging code accidently left in files.c:
	  find_rigid_hash function.

* Wed Jul 18 2008 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Updated documentation to reflect Cygwin Ports support.

	* Modified file_type function to record the file size of 
	  each file processed. This should eliminate the need to
	  call stat again or the ioctl functions in hash.c and
	  hopefully speed up the program.

	* Added timestamp to the output for size mode per Feature
	  Request 2014686. This should be the creation time on 
	  Win32, change time for all other operating systems.

	* Removed 'Experimental cast' tags from SHA256 and Tiger
	  hashing code. They appear to be working.

	* In response to bug 2022302, updated time estimate display
	  to handle large time values, including those more than
	  one day.


* Wed Jul 04 2008 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Added -I mode to display filenames with asterisks for
	  hashes when size is above threshold. Compliments -i mode.
	

* Wed Jul 04 2008 Jesse Kornblum <md5deep@jessekornblumn.com> 

	* Removed SF Community Choice Awards from web page. 
	  The nominations are closed.

	* Added size mode, -i, to only process files smaller than
	  a given size threshold. Reused code from piecewise mode
	  to parse user input. Added to md5deep and hashdeep.
	  Added to SF at Feature Request 2010771.

	
* Sat May 20 2008 Jesse Kornblum <md5deep@jessekornblum.com>

	* New Features

		Added hashdeep program to support multihashing

		Added support for new iLook style hashes

	* Bug Fixes
		
		Fixed obscure bug that caused a crash (double free) when
		attempting to check a very small file for EnCase hashes

* Sat Oct 28 2007 Jesse Kornblum <md5deep@jessekornblum.com>

	* Added additional checks in find_file_size to account for
	  older Linux systems that don't have all of the necessary
	  ioctl calls.

* Tue Oct 16 2007 Jesse Kornblum <md5deep@jessekornblum.com>

	* Incorporated patch from Yaakov Selkowitz to handle man page
	  copying when build dir is not the same as source dir.
	  (Sourceforge tracker #1814253)


* Wed Sep 26 2007 Jesse Kornblum <md5deep@jessekornblum.com>

	* Added second ioctl call in Linux version of find_file_size
	  to get the true sector size; don't just assume 512 byte
	  sectors. 

	* Changed fseek call in hash.c to fseeko for large file support
	
	* Removed spurrious -u: from getopt call in main.c

	* Removed function checks from configure.ac. We weren't using
	  them to build support, so we shouldn't waste time checking
	  for them.
	

* Tue Sep 25 2007 Jesse Kornblum <md5deep@jessekornblum.com>

	* Created new function print_error_unicode to 
	  handle errors encountered while processing
	  files with (possibly) Unicode characters in 
	  their filenames.
	
	* Added AC_SYS_LARGEFILE to configure script to 
	  account for large files on Linux. This fixes
	  the file estimation mode (-e) for Liunx. 

	* Fixed find_file_size for block devices on OS X.

	
* Mon Sep 24 2007 Jesse Kornblum <md5deep@jessekornblum.com>

	* Updated error display for Unicode filenames in dig.c
	
	* Fixed expert mode due to 64-bit values in int returns

	
* Sun Sep 23 2007 Jesse Kornblum <md5deep@jessekornblum.com>

	* Reverted back to old method of installing man pages.
	  When make install is invoked, current md5deep.1 is
	  copied over other man pages, which are all then 
	  installed normally.

	
* Sat Sep 22 2007 Jesse Kornblum <md5deep@jessekornblum.com>

	* Switched to GNU autotools
	
	* Moved list of past changes to NEWS file
	
